@@ -100,7 +100,7 @@ Datetime::Datetime(const Chain& v, const ListT<Chain>& formatList)
     }
 }
 
-Datetime::Datetime(unsigned long long l)
+Datetime::Datetime(long long l)
 {
     _t = (time_t)l;
 }
@@ -164,12 +164,12 @@ long long Datetime::asLong() const
     return (long long)_t;
 }
 
-void Datetime::add(unsigned long long seconds)
+void Datetime::add(long long seconds)
 {
     _t += seconds;
 }
 
-void Datetime::sub(unsigned long long seconds)
+void Datetime::sub(long long seconds)
 {
     _t = _t - seconds;
 }
